﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "Bar 클래스 : MouseEnter/MouseLeave 이벤트를 사용해 특정 막대 추적하기";

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            Bar bar = new Bar(this.tChart.Chart);

            bar.FillSampleValues(6);

            Line Line = new Line(this.tChart.Chart);

            Line.FillSampleValues(6);

            bar.MouseEnter += bar_MouseEnter;
            bar.MouseLeave += bar_MouseLeave;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 바 마우스 진입시 처리하기 - bar_MouseEnter(sender, e)

        /// <summary>
        /// 바 마우스 진입시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void bar_MouseEnter(object sender, EventArgs e)
        {
            Series series = sender as Series;

            int valueIndex = series.Clicked(this.tChart.PointToClient(Cursor.Position));

            this.tChart.Header.Text = $"시리즈 : {series}, 포인트 : {valueIndex}, 값  : {series.YValues.Value[valueIndex]}";
        }

        #endregion
        #region 바 마우스 이탈시 처리하기 - bar_MouseLeave(sender, e)

        /// <summary>
        /// 바 마우스 이탈시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void bar_MouseLeave(object sender, EventArgs e)
        {
            this.tChart.Header.Text = "TeeChart";
        }

        #endregion
    }
}